@@ -19,11 +19,13 @@
 
 #include "capabilitiesjob.h"
 
+#include <KLocalizedString>
+
 #include "job_p.h"
 #include "message_p.h"
 #include "session_p.h"
 
-namespace KIMAP2
+namespace KIMAP
 {
 class CapabilitiesJobPrivate : public JobPrivate
 {
@@ -35,10 +37,10 @@ public:
 };
 }
 
-using namespace KIMAP2;
+using namespace KIMAP;
 
 CapabilitiesJob::CapabilitiesJob(Session *session)
-    : Job(*new CapabilitiesJobPrivate(session, "Capabilities"))
+    : Job(*new CapabilitiesJobPrivate(session, i18n("Capabilities")))
 {
 }
 
@@ -55,7 +57,7 @@ QStringList CapabilitiesJob::capabilities() const
 void CapabilitiesJob::doStart()
 {
     Q_D(CapabilitiesJob);
-    d->sendCommand("CAPABILITY", {});
+    d->tags << d->sessionInternal()->sendCommand("CAPABILITY");
 }
 
 void CapabilitiesJob::handleResponse(const Message &response)
