@@ -19,11 +19,13 @@
 
 #include "closejob.h"
 
+#include <KLocalizedString>
+
 #include "job_p.h"
 #include "message_p.h"
 #include "session_p.h"
 
-namespace KIMAP2
+namespace KIMAP
 {
 class CloseJobPrivate : public JobPrivate
 {
@@ -33,10 +35,10 @@ public:
 };
 }
 
-using namespace KIMAP2;
+using namespace KIMAP;
 
 CloseJob::CloseJob(Session *session)
-    : Job(*new CloseJobPrivate(session, "Close"))
+    : Job(*new CloseJobPrivate(session, i18n("Close")))
 {
 }
 
@@ -47,5 +49,5 @@ CloseJob::~CloseJob()
 void CloseJob::doStart()
 {
     Q_D(CloseJob);
-    d->sendCommand("CLOSE", {});
+    d->tags << d->sessionInternal()->sendCommand("CLOSE");
 }
