@@ -19,6 +19,8 @@
 
 #include "copyjob.h"
 
+#include <KLocalizedString>
+
 #include "job_p.h"
 #include "message_p.h"
 #include "session_p.h"
@@ -26,12 +28,12 @@
 
 //TODO: when custom error codes are introduced, handle the NO [TRYCREATE] response
 
-namespace KIMAP2
+namespace KIMAP
 {
 class CopyJobPrivate : public JobPrivate
 {
 public:
-    CopyJobPrivate(Session *session, const QString &name) : JobPrivate(session, name), uidBased(false) { }
+    CopyJobPrivate(Session *session, const QString &name) : JobPrivate(session, name) { }
     ~CopyJobPrivate() { }
 
     QString mailBox;
@@ -41,10 +43,10 @@ public:
 };
 }
 
-using namespace KIMAP2;
+using namespace KIMAP;
 
 CopyJob::CopyJob(Session *session)
-    : Job(*new CopyJobPrivate(session, "Copy"))
+    : Job(*new CopyJobPrivate(session, i18n("Copy")))
 {
     Q_D(CopyJob);
     d->uidBased = false;
@@ -101,14 +103,14 @@ void CopyJob::doStart()
     Q_D(CopyJob);
 
     QByteArray parameters = d->set.toImapSequenceSet() + ' ';
-    parameters += '\"' + KIMAP2::encodeImapFolderName(d->mailBox.toUtf8()) + '\"';
+    parameters += '\"' + KIMAP::encodeImapFolderName(d->mailBox.toUtf8()) + '\"';
 
     QByteArray command = "COPY";
     if (d->uidBased) {
         command = "UID " + command;
     }
 
-    d->sendCommand(command, parameters);
+    d->tags << d->sessionInternal()->sendCommand(command, parameters);
 }
 
 void CopyJob::handleResponse(const Message &response)
