@@ -19,13 +19,14 @@
 
 #include "expungejob.h"
 
+#include <KLocalizedString>
 #include "kimap_debug.h"
 
 #include "job_p.h"
 #include "message_p.h"
 #include "session_p.h"
 
-namespace KIMAP2
+namespace KIMAP
 {
 class ExpungeJobPrivate : public JobPrivate
 {
@@ -38,10 +39,10 @@ public:
 };
 }
 
-using namespace KIMAP2;
+using namespace KIMAP;
 
 ExpungeJob::ExpungeJob(Session *session)
-    : Job(*new ExpungeJobPrivate(session, "Expunge"))
+    : Job(*new ExpungeJobPrivate(session, i18n("Expunge")))
 {
 }
 
@@ -52,7 +53,7 @@ ExpungeJob::~ExpungeJob()
 void ExpungeJob::doStart()
 {
     Q_D(ExpungeJob);
-    d->sendCommand("EXPUNGE", {});
+    d->tags << d->sessionInternal()->sendCommand("EXPUNGE");
 }
 
 void ExpungeJob::handleResponse(const Message &response)
@@ -60,7 +61,7 @@ void ExpungeJob::handleResponse(const Message &response)
 //  Q_D(ExpungeJob);
 
     if (handleErrorReplies(response) == NotHandled) {
-        if (response.content.size() >= 3) {
+        if (response.content.size() >= 2) {
             QByteArray code = response.content[2].toString();
             if (code == "EXPUNGE") {
 #if 0
@@ -75,7 +76,7 @@ void ExpungeJob::handleResponse(const Message &response)
                 return;
             }
         }
-        qCDebug(KIMAP2_LOG) << "Unhandled response: " << response.toString().constData();
+        qCDebug(KIMAP_LOG) << "Unhandled response: " << response.toString().constData();
 
     }
 }
