@@ -19,6 +19,7 @@
 
 #include "getmetadatajob.h"
 
+#include <KLocalizedString>
 #include "kimap_debug.h"
 
 #include "metadatajobbase_p.h"
@@ -26,7 +27,7 @@
 #include "session_p.h"
 #include "rfccodecs.h"
 
-namespace KIMAP2
+namespace KIMAP
 {
 class GetMetaDataJobPrivate : public MetaDataJobBasePrivate
 {
@@ -43,10 +44,10 @@ public:
 };
 }
 
-using namespace KIMAP2;
+using namespace KIMAP;
 
 GetMetaDataJob::GetMetaDataJob(Session *session)
-    : MetaDataJobBase(*new GetMetaDataJobPrivate(session, "GetMetaData"))
+    : MetaDataJobBase(*new GetMetaDataJobPrivate(session, i18n("GetMetaData")))
 {
 }
 
@@ -65,11 +66,11 @@ void GetMetaDataJob::doStart()
 {
     Q_D(GetMetaDataJob);
     QByteArray parameters;
-    parameters = '\"' + KIMAP2::encodeImapFolderName(d->mailBox.toUtf8()) + "\" ";
+    parameters = '\"' + KIMAP::encodeImapFolderName(d->mailBox.toUtf8()) + "\" ";
 
     QByteArray command = "GETMETADATA";
     if (d->serverCapability == Annotatemore) {
-        d->m_name = "GetAnnotation";
+        d->m_name = i18n("GetAnnotation");
         command = "GETANNOTATION";
         if (d->entries.size() > 1) {
             parameters += '(';
@@ -122,21 +123,21 @@ void GetMetaDataJob::doStart()
         }
     }
 
-    d->sendCommand(command, parameters);
-//  qCDebug(KIMAP2_LOG) << "SENT: " << command << " " << parameters;
+    d->tags << d->sessionInternal()->sendCommand(command, parameters);
+//  qCDebug(KIMAP_LOG) << "SENT: " << command << " " << parameters;
 }
 
 void GetMetaDataJob::handleResponse(const Message &response)
 {
     Q_D(GetMetaDataJob);
-//  qCDebug(KIMAP2_LOG) << "GOT: " << response.toString();
+//  qCDebug(KIMAP_LOG) << "GOT: " << response.toString();
 
     //TODO: handle NO error messages having [METADATA MAXSIZE NNN], [METADATA TOOMANY], [METADATA NOPRIVATE] (see rfc5464)
     // or [ANNOTATEMORE TOOBIG], [ANNOTATEMORE TOOMANY] respectively
     if (handleErrorReplies(response) == NotHandled) {
         if (response.content.size() >= 4) {
             if (d->serverCapability == Annotatemore && response.content[1].toString() == "ANNOTATION") {
-                QString mailBox = QString::fromUtf8(KIMAP2::decodeImapFolderName(response.content[2].toString()));
+                QString mailBox = QString::fromUtf8(KIMAP::decodeImapFolderName(response.content[2].toString()));
 
                 int i = 3;
                 while (i < response.content.size() - 1) {
@@ -150,7 +151,7 @@ void GetMetaDataJob::handleResponse(const Message &response)
                     i += 2;
                 }
             } else if (d->serverCapability == Metadata && response.content[1].toString() == "METADATA") {
-                QString mailBox = QString::fromUtf8(KIMAP2::decodeImapFolderName(response.content[2].toString()));
+                QString mailBox = QString::fromUtf8(KIMAP::decodeImapFolderName(response.content[2].toString()));
 
                 const QList<QByteArray> &entries = response.content[3].toList();
                 int i = 0;
@@ -171,7 +172,7 @@ void GetMetaDataJob::addEntry(const QByteArray &entry, const QByteArray &attribu
 {
     Q_D(GetMetaDataJob);
     if (d->serverCapability == Annotatemore && attribute.isNull()) {
-        qCWarning(KIMAP2_LOG) << "In ANNOTATEMORE mode an attribute must be specified with addEntry!";
+        qCWarning(KIMAP_LOG) << "In ANNOTATEMORE mode an attribute must be specified with addEntry!";
     }
     d->entries.insert(entry);
     d->attributes.insert(attribute);
@@ -226,7 +227,7 @@ QByteArray GetMetaDataJob::metaData(const QString &mailBox, const QByteArray &en
 
 QByteArray GetMetaDataJob::metaData(const QByteArray &entry) const
 {
-    qCDebug(KIMAP2_LOG) << entry;
+    qCDebug(KIMAP_LOG) << entry;
     Q_D(const GetMetaDataJob);
     return d->metadata.value(d->mailBox).value(d->removePrefix(entry)).value(d->getAttribute(entry));
 }
@@ -261,11 +262,8 @@ QHash<QString, QMap<QByteArray, QByteArray> > GetMetaDataJob::allMetaDataForMail
 {
     Q_D(const GetMetaDataJob);
     QHash<QString, QMap<QByteArray, QByteArray> > mailboxHash;
-
-    QMapIterator<QString, QMap<QByteArray, QMap<QByteArray, QByteArray> > > i(d->metadata);
-    while (i.hasNext()) {
-        i.next();
-        mailboxHash.insert(i.key(), allMetaDataForMailbox(i.key()));
+    Q_FOREACH (const QString &mailbox, d->metadata.keys()) {
+        mailboxHash.insert(mailbox, allMetaDataForMailbox(mailbox));
     }
     return mailboxHash;
 }
