@@ -19,12 +19,14 @@
 
 #include "getquotarootjob.h"
 
+#include <KLocalizedString>
+
 #include "quotajobbase_p.h"
 #include "message_p.h"
 #include "session_p.h"
 #include "rfccodecs.h"
 
-namespace KIMAP2
+namespace KIMAP
 {
 class GetQuotaRootJobPrivate : public QuotaJobBasePrivate
 {
@@ -38,10 +40,10 @@ public:
 };
 }
 
-using namespace KIMAP2;
+using namespace KIMAP;
 
 GetQuotaRootJob::GetQuotaRootJob(Session *session)
-    : QuotaJobBase(*new GetQuotaRootJobPrivate(session, "GetQuotaRoot"))
+    : QuotaJobBase(*new GetQuotaRootJobPrivate(session, i18n("GetQuotaRoot")))
 {
 }
 
@@ -52,7 +54,7 @@ GetQuotaRootJob::~GetQuotaRootJob()
 void GetQuotaRootJob::doStart()
 {
     Q_D(GetQuotaRootJob);
-    d->sendCommand("GETQUOTAROOT", '\"' + KIMAP2::encodeImapFolderName(d->mailBox.toUtf8()) + '\"');
+    d->tags << d->sessionInternal()->sendCommand("GETQUOTAROOT", '\"' + KIMAP::encodeImapFolderName(d->mailBox.toUtf8()) + '\"');
 }
 
 void GetQuotaRootJob::handleResponse(const Message &response)
