@@ -17,13 +17,13 @@
     02110-1301, USA.
 */
 
-#ifndef KIMAP2_JOB_P_H
-#define KIMAP2_JOB_P_H
+#ifndef KIMAP_JOB_P_H
+#define KIMAP_JOB_P_H
 
 #include "session.h"
-#include <QtNetwork/QAbstractSocket>
+#include <ktcpsocket.h>
 
-namespace KIMAP2
+namespace KIMAP
 {
 
 class SessionPrivate;
@@ -31,7 +31,7 @@ class SessionPrivate;
 class JobPrivate
 {
 public:
-    JobPrivate(Session *session, const QString &name) : m_session(session), m_socketError(QAbstractSocket::UnknownSocketError)
+    JobPrivate(Session *session, const QString &name) : m_session(session), m_socketError(KTcpSocket::UnknownError)
     {
         m_name = name;
     }
@@ -47,14 +47,10 @@ public:
         return m_session->d;
     }
 
-    void sendCommand(const QByteArray &command, const QByteArray &args);
-
     QList<QByteArray> tags;
     Session *m_session;
     QString m_name;
-    QString m_errorMessage;
-    QString m_currentCommand;
-    QAbstractSocket::SocketError m_socketError;
+    KTcpSocket::Error m_socketError;
 };
 
 }
