@@ -19,12 +19,14 @@
 
 #include "listrightsjob.h"
 
+#include <KLocalizedString>
+
 #include "acljobbase_p.h"
 #include "message_p.h"
 #include "session_p.h"
 #include "rfccodecs.h"
 
-namespace KIMAP2
+namespace KIMAP
 {
 class ListRightsJobPrivate : public AclJobBasePrivate
 {
@@ -38,10 +40,10 @@ public:
 };
 }
 
-using namespace KIMAP2;
+using namespace KIMAP;
 
 ListRightsJob::ListRightsJob(Session *session)
-    : AclJobBase(*new ListRightsJobPrivate(session, "ListRights"))
+    : AclJobBase(*new ListRightsJobPrivate(session, i18n("ListRights")))
 {
 
 }
@@ -54,7 +56,7 @@ void ListRightsJob::doStart()
 {
     Q_D(ListRightsJob);
 
-    d->sendCommand("LISTRIGHTS", '\"' + KIMAP2::encodeImapFolderName(d->mailBox.toUtf8()) + "\" \"" + d->id + "\"");
+    d->tags << d->sessionInternal()->sendCommand("LISTRIGHTS", '\"' + KIMAP::encodeImapFolderName(d->mailBox.toUtf8()) + "\" \"" + d->id + "\"");
 }
 
 void ListRightsJob::handleResponse(const Message &response)
