@@ -19,11 +19,13 @@
 
 #include "logoutjob.h"
 
+#include <KLocalizedString>
+
 #include "job_p.h"
 #include "message_p.h"
 #include "session_p.h"
 
-namespace KIMAP2
+namespace KIMAP
 {
 class LogoutJobPrivate : public JobPrivate
 {
@@ -33,10 +35,10 @@ public:
 };
 }
 
-using namespace KIMAP2;
+using namespace KIMAP;
 
 LogoutJob::LogoutJob(Session *session)
-    : Job(*new LogoutJobPrivate(session, "Logout"))
+    : Job(*new LogoutJobPrivate(session, i18n("Logout")))
 {
 }
 
@@ -47,7 +49,7 @@ LogoutJob::~LogoutJob()
 void LogoutJob::doStart()
 {
     Q_D(LogoutJob);
-    d->sendCommand("LOGOUT", {});
+    d->tags << d->sessionInternal()->sendCommand("LOGOUT");
 }
 
 void LogoutJob::connectionLost()
