@@ -1,6 +1,5 @@
 /*
     Copyright (c) 2009 Kevin Ottens <ervin@kde.org>
-    Copyright (c) 2017 Christian Mollekopf <mollekopf@kolabsys.com>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -18,30 +17,30 @@
     02110-1301, USA.
 */
 
-#ifndef KIMAP2_SESSION_P_H
-#define KIMAP2_SESSION_P_H
+#ifndef KIMAP_SESSION_P_H
+#define KIMAP_SESSION_P_H
 
 #include "session.h"
+#include "sessionuiproxy.h"
 
-#include <QtNetwork/QSslSocket>
+#include <ktcpsocket.h>
 
 #include <QtCore/QObject>
 #include <QtCore/QQueue>
 #include <QtCore/QString>
 #include <QtCore/QTimer>
-#include <QtCore/QTime>
 
 class KJob;
 
-namespace KIMAP2
+namespace KIMAP
 {
 
 class Job;
 struct Message;
 class SessionLogger;
-class ImapStreamParser;
+class SessionThread;
 
-class KIMAP2_EXPORT SessionPrivate : public QObject
+class KIMAP_EXPORT SessionPrivate : public QObject
 {
     Q_OBJECT
 
@@ -53,9 +52,11 @@ public:
 
     void addJob(Job *job);
     QByteArray sendCommand(const QByteArray &command, const QByteArray &args = QByteArray());
-    void startSsl(QSsl::SslProtocol version);
+    void startSsl(const KTcpSocket::SslVersion &version);
     void sendData(const QByteArray &data);
 
+    KTcpSocket::SslVersion negotiatedEncryption() const;
+
     void setSocketTimeout(int ms);
     int socketTimeout() const;
 
@@ -63,27 +64,22 @@ Q_SIGNALS:
     void encryptionNegotiationResult(bool);
 
 private Q_SLOTS:
+    void onEncryptionNegotiationResult(bool isEncrypted, KTcpSocket::SslVersion sslVersion);
     void onSocketTimeout();
-    void onSocketProgressTimeout();
 
     void doStartNext();
     void jobDone(KJob *);
     void jobDestroyed(QObject *);
+    void responseReceived(const KIMAP::Message &);
 
     void socketConnected();
     void socketDisconnected();
-    void socketError(QAbstractSocket::SocketError);
+    void socketError(KTcpSocket::Error);
     void socketActivity();
-    void handleSslErrors(const QList<QSslError> &errors);
 
-    void closeSocket();
-    void reconnect();
-    void readMessage();
-    void writeDataQueue();
-    void sslConnected();
+    void handleSslError(const KSslErrorUiData &errorData);
 
 private:
-    void responseReceived(const KIMAP2::Message &);
     void startNext();
     void clearJobQueue();
     void setState(Session::State state);
@@ -91,15 +87,15 @@ private:
     void startSocketTimer();
     void stopSocketTimer();
     void restartSocketTimer();
-    QString getStateName() const;
 
     Session *const q;
 
     bool isSocketConnected;
     Session::State state;
-    bool hostLookupInProgress;
 
-    QScopedPointer<SessionLogger> logger;
+    SessionLogger *logger;
+    SessionThread *thread;
+    SessionUiProxy::Ptr uiProxy;
 
     bool jobRunning;
     Job *currentJob;
@@ -115,24 +111,10 @@ private:
     QByteArray upcomingMailBox;
     quint16 tagCount;
 
+    KTcpSocket::SslVersion sslVersion;
+
     int socketTimerInterval;
     QTimer socketTimer;
-    int socketProgressInterval;
-    QTimer socketProgressTimer;
-
-    QString hostName;
-    quint16 port;
-
-    QScopedPointer<QSslSocket> socket;
-    QScopedPointer<ImapStreamParser> stream;
-
-    QQueue<QByteArray> dataQueue;
-
-    QTime time;
-    qint64 accumulatedWaitTime;
-    qint64 accumulatedProcessingTime;
-    bool trackTime;
-    bool dumpTraffic;
 };
 
 }
