@@ -22,13 +22,9 @@
 
 #include "kimap_debug.h"
 
-#ifdef WIN32
-#include <process.h>
-#else
-#include <unistd.h> //for getpid()
-#endif
+#include <unistd.h>
 
-using namespace KIMAP2;
+using namespace KIMAP;
 
 SessionLogger::SessionLogger()
     : m_id(0)
@@ -36,16 +32,11 @@ SessionLogger::SessionLogger()
     static qint64 nextId = 0;
     m_id = ++nextId;
 
-    m_file.setFileName(QLatin1String(qgetenv("KIMAP2_LOGFILE"))
-                       + QLatin1Char('.')
-#ifdef WIN32
-                       + QString::number(_getpid())
-#else
-                       + QString::number(getpid())
-#endif
+    m_file.setFileName(QLatin1String(qgetenv("KIMAP_LOGFILE"))
+                       + QLatin1Char('.') + QString::number(getpid())
                        + QLatin1Char('.') + QString::number(m_id));
     if (!m_file.open(QFile::WriteOnly)) {
-        qCDebug(KIMAP2_LOG) << " m_file can be open in write only";
+        qCDebug(KIMAP_LOG) << " m_file can be open in write only";
     }
 }
 
