@@ -19,12 +19,14 @@
 
 #include "setacljob.h"
 
+#include <KLocalizedString>
+
 #include "acljobbase_p.h"
 #include "message_p.h"
 #include "session_p.h"
 #include "rfccodecs.h"
 
-namespace KIMAP2
+namespace KIMAP
 {
 class SetAclJobPrivate : public AclJobBasePrivate
 {
@@ -34,10 +36,10 @@ public:
 };
 }
 
-using namespace KIMAP2;
+using namespace KIMAP;
 
 SetAclJob::SetAclJob(Session *session)
-    : AclJobBase(*new SetAclJobPrivate(session, "SetAcl"))
+    : AclJobBase(*new SetAclJobPrivate(session, i18n("SetAcl")))
 {
 }
 
@@ -54,7 +56,7 @@ void SetAclJob::doStart()
     } else if (d->modifier == Remove) {
         r.prepend('-');
     }
-    d->sendCommand("SETACL", '\"' + KIMAP2::encodeImapFolderName(d->mailBox.toUtf8()) + "\" \"" + d->id + "\" \"" + r + '\"');
+    d->tags << d->sessionInternal()->sendCommand("SETACL", '\"' + KIMAP::encodeImapFolderName(d->mailBox.toUtf8()) + "\" \"" + d->id + "\" \"" + r + '\"');
 }
 
 void SetAclJob::setRights(AclModifier modifier, Acl::Rights rights)
