@@ -20,12 +20,13 @@
 #include "storejob.h"
 
 #include "kimap_debug.h"
+#include <KLocalizedString>
 
 #include "job_p.h"
 #include "message_p.h"
 #include "session_p.h"
 
-namespace KIMAP2
+namespace KIMAP
 {
 class StoreJobPrivate : public JobPrivate
 {
@@ -70,10 +71,10 @@ public:
 };
 }
 
-using namespace KIMAP2;
+using namespace KIMAP;
 
 StoreJob::StoreJob(Session *session)
-    : Job(*new StoreJobPrivate(session, "Store"))
+    : Job(*new StoreJobPrivate(session, i18n("Store")))
 {
     Q_D(StoreJob);
     d->uidBased = false;
@@ -155,7 +156,7 @@ void StoreJob::doStart()
     Q_D(StoreJob);
 
     if (d->set.isEmpty()) {
-        qCWarning(KIMAP2_LOG) << "Empty uid set passed to store job";
+        qCWarning(KIMAP_LOG) << "Empty uid set passed to store job";
         setError(KJob::UserDefinedError);
         setErrorText(QStringLiteral("Empty uid set passed to store job"));
         emitResult();
@@ -164,7 +165,7 @@ void StoreJob::doStart()
 
     QByteArray parameters = d->set.toImapSequenceSet() + ' ';
 
-    if (!d->flags.isEmpty() || d->mode == SetFlags) {
+    if (!d->flags.isEmpty()) {
         parameters += d->addFlags("FLAGS", d->flags);
     }
     if (!d->gmLabels.isEmpty()) {
@@ -174,14 +175,14 @@ void StoreJob::doStart()
         parameters += d->addFlags("X-GM-LABELS", d->gmLabels);
     }
 
-    qCDebug(KIMAP2_LOG) << parameters;
+    qCDebug(KIMAP_LOG) << parameters;
 
     QByteArray command = "STORE";
     if (d->uidBased) {
         command = "UID " + command;
     }
 
-    d->sendCommand(command, parameters);
+    d->tags << d->sessionInternal()->sendCommand(command, parameters);
 }
 
 void StoreJob::handleResponse(const Message &response)
@@ -224,7 +225,7 @@ void StoreJob::handleResponse(const Message &response)
             } else if (uidFound) {
                 d->resultingFlags[uid] = resultingFlags;
             } else {
-                qCWarning(KIMAP2_LOG) << "We asked for UID but the server didn't give it back, resultingFlags not stored.";
+                qCWarning(KIMAP_LOG) << "We asked for UID but the server didn't give it back, resultingFlags not stored.";
             }
         }
     }
