@@ -19,12 +19,14 @@
 
 #include "subscribejob.h"
 
+#include <KLocalizedString>
+
 #include "job_p.h"
 #include "message_p.h"
 #include "session_p.h"
 #include "rfccodecs.h"
 
-namespace KIMAP2
+namespace KIMAP
 {
 class SubscribeJobPrivate : public JobPrivate
 {
@@ -36,10 +38,10 @@ public:
 };
 }
 
-using namespace KIMAP2;
+using namespace KIMAP;
 
 SubscribeJob::SubscribeJob(Session *session)
-    : Job(*new SubscribeJobPrivate(session, "Subscribe"))
+    : Job(*new SubscribeJobPrivate(session, i18n("Subscribe")))
 {
 }
 
@@ -50,7 +52,7 @@ SubscribeJob::~SubscribeJob()
 void SubscribeJob::doStart()
 {
     Q_D(SubscribeJob);
-    d->sendCommand("SUBSCRIBE", '\"' + KIMAP2::encodeImapFolderName(d->mailBox.toUtf8()) + '\"');
+    d->tags << d->sessionInternal()->sendCommand("SUBSCRIBE", '\"' + KIMAP::encodeImapFolderName(d->mailBox.toUtf8()) + '\"');
 }
 
 void SubscribeJob::setMailBox(const QString &mailBox)
