@@ -19,12 +19,14 @@
 
 #include "unsubscribejob.h"
 
+#include <KLocalizedString>
+
 #include "job_p.h"
 #include "message_p.h"
 #include "session_p.h"
 #include "rfccodecs.h"
 
-namespace KIMAP2
+namespace KIMAP
 {
 class UnsubscribeJobPrivate : public JobPrivate
 {
@@ -36,10 +38,10 @@ public:
 };
 }
 
-using namespace KIMAP2;
+using namespace KIMAP;
 
 UnsubscribeJob::UnsubscribeJob(Session *session)
-    : Job(*new UnsubscribeJobPrivate(session, "Unsubscribe"))
+    : Job(*new UnsubscribeJobPrivate(session, i18n("Unsubscribe")))
 {
 }
 
@@ -50,7 +52,7 @@ UnsubscribeJob::~UnsubscribeJob()
 void UnsubscribeJob::doStart()
 {
     Q_D(UnsubscribeJob);
-    d->sendCommand("UNSUBSCRIBE", '\"' + KIMAP2::encodeImapFolderName(d->mailBox.toUtf8()) + '\"');
+    d->tags << d->sessionInternal()->sendCommand("UNSUBSCRIBE", '\"' + KIMAP::encodeImapFolderName(d->mailBox.toUtf8()) + '\"');
 }
 
 void UnsubscribeJob::setMailBox(const QString &mailBox)
