@@ -18,11 +18,7 @@
   * Boston, MA 02110-1301, USA.
   */
 
-#include <kcomponentdata.h>
-#include <k4aboutdata.h>
-#include <klocalizedstring.h>
 #include <qdebug.h>
-#include <ktcpsocket.h> // declares KSslErrorUiData
 #include <QCoreApplication>
 #include <qsignalspy.h>
 
@@ -49,8 +45,7 @@ public:
 
 int main(int argc, char **argv)
 {
-    K4AboutData about("TestImapIdle", 0, ki18n("TestImapIdle"), "version");
-    KComponentData cData(&about);
+    QCoreApplication::setApplicationName(QStringLiteral("TestImapIdle"));
 
     if (argc < 4) {
         qCritical() << "Not enough parameters, expecting: <server> <user> <password>";
@@ -90,11 +85,11 @@ int main(int argc, char **argv)
     qDebug() << capabilities->capabilities();
     qDebug();
 
-    Q_ASSERT(capabilities->capabilities().contains(QLatin1String("IDLE")));
+    Q_ASSERT(capabilities->capabilities().contains(QStringLiteral("IDLE")));
 
     qDebug() << "Selecting INBOX:";
     SelectJob *select = new SelectJob(&session);
-    select->setMailBox(QLatin1String("INBOX"));
+    select->setMailBox(QStringLiteral("INBOX"));
     select->exec();
     Q_ASSERT_X(select->error() == 0, "SelectJob", select->errorString().toLocal8Bit().constData());
     Q_ASSERT(session.state() == Session::Selected);
