@@ -19,10 +19,7 @@
   * Boston, MA 02110-1301, USA.
   */
 
-#include <kcomponentdata.h>
-#include <k4aboutdata.h>
 #include <qdebug.h>
-#include <klocalizedstring.h>
 #include <qtcpsocket.h>
 #include <QCoreApplication>
 #include <qsignalspy.h>
@@ -61,6 +58,7 @@ class UiProxy: public SessionUiProxy
 public:
     bool ignoreSslError(const KSslErrorUiData &errorData)
     {
+        Q_UNUSED(errorData);
         return true;
     }
 };
@@ -106,25 +104,25 @@ void testMetaData(Session *session)
 {
     qDebug() << "TESTING: METADATA commands";
     CreateJob *create = new CreateJob(session);
-    create->setMailBox(QLatin1String("INBOX/TestFolder"));
+    create->setMailBox(QStringLiteral("INBOX/TestFolder"));
     create->exec();
 
     SetMetaDataJob *setmetadata = new SetMetaDataJob(session);
-    setmetadata->setMailBox(QLatin1String("INBOX/TestFolder"));
+    setmetadata->setMailBox(QStringLiteral("INBOX/TestFolder"));
     setmetadata->setServerCapability(SetMetaDataJob::Annotatemore);
     setmetadata->setEntry("/comment");
     setmetadata->addMetaData("value.priv", "My new comment");
     setmetadata->exec();
 
     setmetadata = new SetMetaDataJob(session);
-    setmetadata->setMailBox(QLatin1String("INBOX/TestFolder"));
+    setmetadata->setMailBox(QStringLiteral("INBOX/TestFolder"));
     setmetadata->setServerCapability(SetMetaDataJob::Annotatemore);
     setmetadata->setEntry("/check");
     setmetadata->addMetaData("value.priv", "true");
     setmetadata->exec();
 
     GetMetaDataJob *getmetadata = new GetMetaDataJob(session);
-    getmetadata->setMailBox(QLatin1String("INBOX/TestFolder"));
+    getmetadata->setMailBox(QStringLiteral("INBOX/TestFolder"));
     getmetadata->setServerCapability(SetMetaDataJob::Annotatemore);
     getmetadata->addEntry("/*", "value.priv");
     getmetadata->exec();
@@ -278,15 +276,15 @@ void testAppendAndStore(Session *session)
     Q_ASSERT(expectedFlags == resultingFlags);
 
     select = new SelectJob(session);
-    select->setMailBox(QLatin1String("INBOX"));
+    select->setMailBox(QStringLiteral("INBOX"));
     select->exec();
 
     //cleanup
     DeleteJob *deletejob = new DeleteJob(session);
-    deletejob->setMailBox(QLatin1String("INBOX/TestFolder"));
+    deletejob->setMailBox(QStringLiteral("INBOX/TestFolder"));
     deletejob->exec();
     deletejob = new DeleteJob(session);
-    deletejob->setMailBox(QLatin1String("INBOX/RenamedTestFolder"));
+    deletejob->setMailBox(QStringLiteral("INBOX/RenamedTestFolder"));
     deletejob->exec();
 }
 
@@ -378,8 +376,7 @@ void testDelete(Session *session)
 
 int main(int argc, char **argv)
 {
-    K4AboutData about("TestImapServer", 0, ki18n("TestImapServer"), "version");
-    KComponentData cData(&about);
+    QCoreApplication::setApplicationName(QStringLiteral("TestImapServer"));
 
     if (argc < 4) {
         qCritical() << "Not enough parameters, expecting: <server> <user> <password>";
@@ -523,7 +520,7 @@ int main(int argc, char **argv)
     Q_ASSERT_X(fetch->error() == 0, "FetchJob", fetch->errorString().toLocal8Bit().constData());
     Q_ASSERT(session.state() == Session::Selected);
     MessagePtr message = fetch->messages()[1];
-    dumpContentHelper(message.get());
+    dumpContentHelper(message.data());
     qDebug();
 
     qDebug() << "Fetching first message second part headers:";
